==> javascript-frontend-2.10-sources.jar: org/sonar/javascript/tree/impl/declaration/ImportClauseTreeImpl.java <==
/*
 * SonarQube JavaScript Plugin
 * Copyright (C) 2011-2016 SonarSource SA
 * mailto:contact AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.javascript.tree.impl.declaration;

import com.google.common.collect.Iterators;
import java.util.Iterator;
import javax.annotation.Nullable;
import org.sonar.javascript.tree.impl.JavaScriptTree;
import org.sonar.javascript.tree.impl.lexical.InternalSyntaxToken;
import org.sonar.plugins.javascript.api.tree.Tree;
import org.sonar.plugins.javascript.api.tree.declaration.DeclarationTree;
import org.sonar.plugins.javascript.api.tree.declaration.ImportClauseTree;
import org.sonar.plugins.javascript.api.tree.expression.IdentifierTree;
import org.sonar.plugins.javascript.api.tree.lexical.SyntaxToken;
import org.sonar.plugins.javascript.api.visitors.TreeVisitor;

public class ImportClauseTreeImpl extends JavaScriptTree implements ImportClauseTree {

  private IdentifierTree defaultImport;
  private SyntaxToken commaToken;
  private DeclarationTree namedImport;

  public ImportClauseTreeImpl(IdentifierTree defaultImport) {
    this.defaultImport = defaultImport;

  }

  public ImportClauseTreeImpl(DeclarationTree namedImport) {
    this.namedImport = namedImport;

  }

  public ImportClauseTreeImpl(IdentifierTree defaultImport, InternalSyntaxToken commaToken, DeclarationTree namedImport) {
    this.defaultImport = defaultImport;
    this.commaToken = commaToken;
    this.namedImport = namedImport;

  }

  @Nullable
  @Override
  public IdentifierTree defaultImport() {
    return defaultImport;
  }

  @Nullable
  @Override
  public SyntaxToken commaToken() {
    return commaToken;
  }

  @Nullable
  @Override
  public DeclarationTree namedImport() {
    return namedImport;
  }

  @Override
  public Kind getKind() {
    return Kind.IMPORT_CLAUSE;
  }

  @Override
  public Iterator<Tree> childrenIterator() {
    return Iterators.forArray(defaultImport, commaToken, namedImport);
  }

  @Override
  public void accept(TreeVisitor visitor) {
    visitor.visitImportClause(this);
  }
}

==> javascript-frontend-2.17.0.3154-sources.jar: org/sonar/javascript/tree/impl/declaration/ImportClauseTreeImpl.java <==
/*
 * SonarQube JavaScript Plugin
 * Copyright (C) 2011-2016 SonarSource SA
 * mailto:contact AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.javascript.tree.impl.declaration;

import com.google.common.collect.Iterators;
import java.util.Iterator;
import javax.annotation.Nullable;
import org.sonar.javascript.tree.impl.JavaScriptTree;
import org.sonar.javascript.tree.impl.lexical.InternalSyntaxToken;
import org.sonar.plugins.javascript.api.tree.Tree;
import org.sonar.plugins.javascript.api.tree.declaration.DeclarationTree;
import org.sonar.plugins.javascript.api.tree.declaration.ImportClauseTree;
import org.sonar.plugins.javascript.api.tree.expression.IdentifierTree;
import org.sonar.plugins.javascript.api.tree.lexical.SyntaxToken;
import org.sonar.plugins.javascript.api.visitors.DoubleDispatchVisitor;

public class ImportClauseTreeImpl extends JavaScriptTree implements ImportClauseTree {

  private IdentifierTree defaultImport;
  private SyntaxToken commaToken;
  private DeclarationTree namedImport;

  public ImportClauseTreeImpl(IdentifierTree defaultImport) {
    this.defaultImport = defaultImport;

  }

  public ImportClauseTreeImpl(DeclarationTree namedImport) {
    this.namedImport = namedImport;

  }

  public ImportClauseTreeImpl(IdentifierTree defaultImport, InternalSyntaxToken commaToken, DeclarationTree namedImport) {
    this.defaultImport = defaultImport;
    this.commaToken = commaToken;
    this.namedImport = namedImport;

  }

  @Nullable
  @Override
  public IdentifierTree defaultImport() {
    return defaultImport;
  }

  @Nullable
  @Override
  public SyntaxToken commaToken() {
    return commaToken;
  }

  @Nullable
  @Override
  public DeclarationTree namedImport() {
    return namedImport;
  }

  @Override
  public Kind getKind() {
    return Kind.IMPORT_CLAUSE;
  }

  @Override
  public Iterator<Tree> childrenIterator() {
    return Iterators.forArray(defaultImport, commaToken, namedImport);
  }

  @Override
  public void accept(DoubleDispatchVisitor visitor) {
    visitor.visitImportClause(this);
  }
}
